package com.biganto.visual.roompark.presentation.screen.estate

import android.view.View
import androidx.recyclerview.widget.RecyclerView
import butterknife.BindView
import com.biganto.visual.roompark.R
import com.biganto.visual.roompark.base.RoomParkApplication
import com.biganto.visual.roompark.base.RoomParkMainActivity
import com.biganto.visual.roompark.conductor.BigantoBaseController
import com.google.android.material.tabs.TabLayout
import com.google.android.material.textview.MaterialTextView
import timber.log.Timber
import javax.inject.Inject

/**
 * Created by Vladislav Bogdashkin on 30.09.2019.
 */

class EstateScreenController  :
    BigantoBaseController<EstateScreenViewState
        , EstateScreen
        , EstateScreenPresenter>()
    , EstateScreen {

    override fun injectDependencies() {
        getComponent()
    }

    @Inject
    override lateinit var injectedPresenter: EstateScreenPresenter

    @BindView(R.id.favorites_cards_recycler_view)
    lateinit var favoritesRecyclerView: RecyclerView

    @BindView(R.id.planTypesTabs)
    lateinit var planTypesTabLayout: TabLayout


    private fun setToolbar(){
        toolBar.showAll()
        toolBar.appBar.setExpanded(false,false)
        toolBar.collapsingToolbarLayout.title = "ИЗБРАННОЕ"
        toolBar.appBar.liftOnScrollTargetViewId = R.id.favorites_cards_recycler_view
        toolBar.appBar.setLiftable(true)
        toolBar.appBarScrollable(false)
        favoritesRecyclerView.isNestedScrollingEnabled = false

//        planTypesTabLayout.
    }

    private fun bindRecycler() {

    }

    override fun onViewBound(v: View) {
        setToolbar()
        bindRecycler()
    }

    override fun render(viewState: EstateScreenViewState) {
        super.render(viewState)
        Timber.d("Render state $viewState")
        when(viewState){
            is EstateScreenViewState.Idle -> render(viewState)
            is EstateScreenViewState.LoadEstate -> render(viewState)
            is EstateScreenViewState.LoadPlanTypes -> render(viewState)
            is EstateScreenViewState.SomeError -> render(viewState)
        }
    }

    private fun render(viewState: EstateScreenViewState.Idle){

    }

    private fun render(viewState: EstateScreenViewState.SomeError) =
        showError(viewState.exception)


    private fun render(viewState: EstateScreenViewState.LoadEstate) {
    }


    private fun render(viewState: EstateScreenViewState.LoadPlanTypes) {
        planTypesTabLayout.removeAllTabs()
        var i = 1
        viewState.types.forEach {
            val tab = planTypesTabLayout.newTab()
                .setCustomView(R.layout.select_text_tab).setTag(it.planTypeId)
            tab.customView?.findViewById<MaterialTextView>(R.id.textTitle)?.text = "Вариант $i"
            i++
        }
    }

    private fun getComponent() = DaggerEstateScreenComponent.factory()
        .create(RoomParkApplication.component,activity as RoomParkMainActivity)
        .inject(this)

    override fun getLayoutId(): Int = R.layout.flat_full_card_screen


}