package com.biganto.visual.roompark.presentation.screen.estate

import com.biganto.visual.roompark.conductor.BigantoBasePresenter
import com.biganto.visual.roompark.domain.interactor.EstateInteractor
import com.biganto.visual.roompark.util.monades.ExceptionString
import io.reactivex.android.schedulers.AndroidSchedulers
import io.reactivex.schedulers.Schedulers
import timber.log.Timber
import javax.inject.Inject

/**
 * Created by Vladislav Bogdashkin on 30.09.2019.
 */


class EstateScreenPresenter @Inject constructor(
    private val interactor: EstateInteractor
)
    : BigantoBasePresenter<EstateScreen, EstateScreenViewState>() {

    override fun defaultErrorViewStateHandler() =
        {e: ExceptionString -> EstateScreenViewState.SomeError(e) }

    override fun bindIntents() {

        val prefetchCards = interactor.getEstate(1)
            //.map { EstateScreenViewState.FavoriteEstatesLoaded(it) }

        val state = restoreStateObservable
            .mergeWith(prefetchCards)
            .doOnError{ Timber.e(it)}
            .subscribeOn(Schedulers.io())
            .observeOn(AndroidSchedulers.mainThread())

        subscribeViewState(state.cast(EstateScreenViewState::class.java), EstateScreen::render)
    }

}